<?php
/**
 * Functions file.
 * 
 * To our understanding, this can be used to add arbitrary PHP code to our theme
 * (very similar to a plugin) and to tell WordPress about the abilities of our theme.
 * 
 * @see https://developer.wordpress.org/themes/basics/theme-functions/
 */

// We support post thumbnails (now known as "featured images"). A post thumbnail is displayed
// in the header of a post.
// If there is no post thumbnail specified, we fall back to a default header image...
add_theme_support('post-thumbnails');

// ...which can also be customized (site-wide)
add_theme_support('custom-header', array(
    'default-image' => get_template_directory_uri().'/img/header.jpg', 
    'uploads'       => true)
);

// And we also support a custom menu in the header
// See https://developer.wordpress.org/reference/functions/register_nav_menu/
function register_fscoli_header_menu() {
    register_nav_menu('header-menu', 'Header-Menü');
}
add_action('init', 'register_fscoli_header_menu');

// We also allow the uploading of TeX files, which are blocked by default
function fscoli_mime_types($mime_types){
    $mime_types['tex'] = 'text/x-tex'; //TeX files
    return $mime_types;
}
add_filter('upload_mimes', 'fscoli_mime_types', 1, 1);

/* 
 * Add support to embed umap (umap.openstreetmap.de)
 * See https://wordpress.org/support/article/embeds/#adding-support-for-a-non-oembed-site
 * For more details on the parameters this function is called with, see also
 * https://developer.wordpress.org/reference/classes/wp_embed/get_embed_handler_html/
 */
function fscoli_embed_umap($regex_matches, $embed_attrs, $url, $raw_embed_attrs) {
    $width = esc_attr(
        is_numeric($embed_attrs['width']) ? $embed_attrs['width']."px" : "auto"
    );

    $height = esc_attr(
        is_numeric($embed_attrs['height']) ? $embed_attrs['height']."px" : "auto"
    );
    
    $url = esc_url($url);
    return <<<HTML
        <iframe src="$url" style="width: $width; height: $height" allow="fullscreen"></iframe>
    HTML;
}
wp_embed_register_handler('umap', '#^https://umap.openstreetmap.de/[a-z]{2}/map/[^/]*#', 'fscoli_embed_umap');
?>
